from prompt_template import system_template_text, user_template_text
from langchain_openai import ChatOpenAI
from langchain.output_parsers import PydanticOutputParser
from langchain.prompts import ChatPromptTemplate
from xiaohongshu_model import Xiaohongshu

# import os  # 環境変数からAPIキーを取得する場合に使用（現在コメントアウト）

def generate_xiaohongshu(theme, openai_api_key):
    """
    レッドブック（RedBook）向けの投稿を AI で生成する関数。

    Args:
        theme (str): 投稿のテーマ
        openai_api_key (str): OpenAI APIキー

    Returns:
        Xiaohongshu: 生成されたレッドブックの投稿データ（タイトル5つ＋本文）
    """

    # ChatGPT へのプロンプトテンプレートを作成
    # `system_template_text` → システム側の指示（投稿のルールなど）
    # `user_template_text` → ユーザーの入力（テーマ）
    prompt = ChatPromptTemplate.from_messages([
        ("system", system_template_text),  # システムメッセージ（ガイドライン）
        ("user", user_template_text)  # ユーザーの入力
    ])

    # OpenAI の GPT-3.5 Turbo モデルを使用
    model = ChatOpenAI(model="gpt-3.5-turbo", api_key=openai_api_key)

    # AI の出力を `Xiaohongshu`（Pydantic モデル）に変換するためのパーサー
    output_parser = PydanticOutputParser(pydantic_object=Xiaohongshu)

    # LangChain の `|` 演算子を使い、プロンプト → AI モデル → パーサーの処理を一連の流れとして構築
    chain = prompt | model | output_parser

    # AI にリクエストを送り、テーマに基づいたレッドブックの投稿データを生成
    result = chain.invoke({
        "parser_instructions": output_parser.get_format_instructions(),  # 出力フォーマットの指示
        "theme": theme  # ユーザーが指定したテーマ
    })

    return result  # 生成された投稿データ（タイトル5つ＋本文）

# # 動作確認（APIキーが環境変数にある場合に使用）
# print(generate_xiaohongshu("大模型", os.getenv("OPENAI_API_KEY")))
